Module root

Module root 

Structs

Root
A temporary binder of RootSend and RootLocal dictionaries, used for providing a unified dictionary to the user.
RootLocal
Holds a root dictionary of trait objects that implement Access and are therefore Interact-able. These are most likely objects that are held locally behind an Rc.
RootSend
Holds a root dictionary of Send-able trait objects that implement Access and are therefore Interact-able. These are most likely objects that are held globally behind an Arc.