Holds a root dictionary of trait objects that implement Access and are therefore Interact-able.
These are most likely objects that are held locally behind an Rc.
Holds a root dictionary of Send-able trait objects that implement Access and are therefore
Interact-able. These are most likely objects that are held globally behind an Arc.